@@ -37,7 +37,10 @@ from nxstools.nxscreator import (
 #: (:obj:`bool`) True if PyTango available
 PYTANGO = False
 try:
-    __import__("PyTango")
+    try:
+        __import__("tango")
+    except Exception:
+        __import__("PyTango")
     PYTANGO = True
 except Exception:
     pass
@@ -1214,7 +1217,7 @@ class SECoPCP(Runner):
         + " in the local directory for the node configured" \
         + " with the json file \n" \
         + "\n" \
-        + "       nxscreate secopcp T -p 5001 -b \n" \
+        + "       nxscreate secopcp T -t 5001 -b \n" \
         + "\n" \
         + "           - create the component for the T secop module " \
         + " in the NXSConfigServer database for the node on the port 5000 \n" \
