@@ -997,6 +997,22 @@ standardComponentVariables = {
     },
     'description': {
     },
+    'sampledescriptiontext': {
+        'sname': {
+            'default': 'sample',
+            'doc': "sample group name (string)"
+        },
+        'description': {
+            'default': "",
+            'doc': "sample description or sampleId (string)"
+        },
+    },
+    'sampledescription': {
+        'sname': {
+            'default': 'sample',
+            'doc': "sample group name (string)"
+        },
+    },
     'defaultinstrument': {
         'control': {
             'default': None,
@@ -1503,6 +1519,13 @@ standardComponentTemplateFiles = {
     'descriptiontext': [
         'descriptiontext.xml',
     ],
+    'sampledescription': [
+        'sampledescription.xml',
+        'sample_description.ds.xml',
+    ],
+    'sampledescriptiontext': [
+        'sampledescriptiontext.xml',
+    ],
     'default': [
         'default.xml',
         'defaultsample.xml',
